@@ -5,20 +5,19 @@ import os
 from typing import Generator
 from typing import Sequence
 
+from pre_commit import lang_base
 from pre_commit.envcontext import envcontext
 from pre_commit.envcontext import PatchesT
 from pre_commit.envcontext import SubstitutionT
 from pre_commit.envcontext import UNSET
 from pre_commit.envcontext import Var
-from pre_commit.hook import Hook
-from pre_commit.languages import helpers
 from pre_commit.prefix import Prefix
-from pre_commit.util import clean_path_on_failure
 from pre_commit.util import cmd_output_b
 
 ENVIRONMENT_DIR = 'conda'
-get_default_version = helpers.basic_get_default_version
-health_check = helpers.basic_health_check
+get_default_version = lang_base.basic_get_default_version
+health_check = lang_base.basic_health_check
+run_hook = lang_base.basic_run_hook
 
 
 def get_env_patch(env: str) -> PatchesT:
@@ -41,12 +40,8 @@ def get_env_patch(env: str) -> PatchesT:
 
 
 @contextlib.contextmanager
-def in_env(
-        prefix: Prefix,
-        language_version: str,
-) -> Generator[None, None, None]:
-    directory = helpers.environment_dir(ENVIRONMENT_DIR, language_version)
-    envdir = prefix.path(directory)
+def in_env(prefix: Prefix, version: str) -> Generator[None, None, None]:
+    envdir = lang_base.environment_dir(prefix, ENVIRONMENT_DIR, version)
     with envcontext(get_env_patch(envdir)):
         yield
 
@@ -65,32 +60,17 @@ def install_environment(
         version: str,
         additional_dependencies: Sequence[str],
 ) -> None:
-    helpers.assert_version_default('conda', version)
-    directory = helpers.environment_dir(ENVIRONMENT_DIR, version)
+    lang_base.assert_version_default('conda', version)
 
     conda_exe = _conda_exe()
 
-    env_dir = prefix.path(directory)
-    with clean_path_on_failure(env_dir):
+    env_dir = lang_base.environment_dir(prefix, ENVIRONMENT_DIR, version)
+    cmd_output_b(
+        conda_exe, 'env', 'create', '-p', env_dir, '--file',
+        'environment.yml', cwd=prefix.prefix_dir,
+    )
+    if additional_dependencies:
         cmd_output_b(
-            conda_exe, 'env', 'create', '-p', env_dir, '--file',
-            'environment.yml', cwd=prefix.prefix_dir,
+            conda_exe, 'install', '-p', env_dir, *additional_dependencies,
+            cwd=prefix.prefix_dir,
         )
-        if additional_dependencies:
-            cmd_output_b(
-                conda_exe, 'install', '-p', env_dir, *additional_dependencies,
-                cwd=prefix.prefix_dir,
-            )
-
-
-def run_hook(
-        hook: Hook,
-        file_args: Sequence[str],
-        color: bool,
-) -> tuple[int, bytes]:
-    # TODO: Some rare commands need to be run using `conda run` but mostly we
-    #       can run them without which is much quicker and produces a better
-    #       output.
-    # cmd = ('conda', 'run', '-p', env_dir) + hook.cmd
-    with in_env(hook.prefix, hook.language_version):
-        return helpers.run_xargs(hook, hook.cmd, file_args, color=color)
